@@ -77,7 +77,7 @@ def increase_counter(contextvar: ContextVar[int]) -> Iterator[None]:
 def json_dumps(element: object) -> str:
 
     def encoder(obj: Any) -> Any:
-        if isinstance(obj, (set, tuple)):
+        if isinstance(obj, (list, set, tuple)):
             casted_obj: Any = list(map(encoder, obj))
         elif isinstance(obj, NamedTuple):
             casted_obj = dict(zip(obj._fields, encoder(tuple(obj))))
